@@ -69,7 +69,7 @@ class TalosConsumerConfigKeys:
     # The consumer switch for whether checking lastCommitOffset or not
     # when commit offset
     GALAXY_TALOS_CONSUMER_CHECK_LAST_COMMIT_OFFSET_SWITCH = "galaxy.talos.consumer.check.last.commit.offset.switch"
-    GALAXY_TALOS_CONSUMER_CHECK_LAST_COMMIT_OFFSET_SWITCH_DEFAULT = True
+    GALAXY_TALOS_CONSUMER_CHECK_LAST_COMMIT_OFFSET_SWITCH_DEFAULT = False
 
     # The consumer partitionFetcher sleep / delay time when partitionNotServing
     GALAXY_TALOS_CONSUMER_WAIT_PARTITION_WORKING_TIME = "galaxy.talos.consumer.wait.partition.working.time.milli"
