@@ -79,8 +79,8 @@ class ProducerMetrics(object):
         self.producerMetricsMap[Constants.PUT_MESSAGE_TIME] = self.putMsgDuration
         self.producerMetricsMap[Constants.MAX_PUT_MESSAGE_TIME] = self.maxPutMsgDuration
         self.producerMetricsMap[Constants.MIN_PUT_MESSAGE_TIME] = self.minPutMsgDuration
-        self.producerMetricsMap[Constants.PUT_MESSAGE_TIMES] = self.putMsgTimes / 60.0
-        self.producerMetricsMap[Constants.PUT_MESSAGE_FAILED_TIMES] = self.putMsgFailedTimes/ 60.0
+        self.producerMetricsMap[Constants.PUT_MESSAGE_TIMES] = int(self.putMsgTimes / 60.0)
+        self.producerMetricsMap[Constants.PUT_MESSAGE_FAILED_TIMES] = int(self.putMsgFailedTimes/ 60.0)
 
     def get_basic_data(self):
         tag = "clusterName=" + self.talosProducerConfig.get_cluster_name()
@@ -91,8 +91,8 @@ class ProducerMetrics(object):
 
         basicData = dict()
         basicData["endpoint"] = self.falconEndpoint
-        basicData["timestamp"] = Utils.current_time_mills() / 1000
-        basicData["step"] = self.talosProducerConfig.get_metric_falcon_step() / 1000
+        basicData["timestamp"] = int(Utils.current_time_mills() / 1000)
+        basicData["step"] = int(self.talosProducerConfig.get_metric_falcon_step() / 1000)
         basicData["counterType"] = "GAUGE"
         basicData["tags"] = tag
         return basicData
