@@ -8,8 +8,6 @@ from talos.thrift.topic.ttypes import GetTopicAttributeRequest
 from talos.thrift.topic.ttypes import GetTopicAttributeResponse
 from talos.thrift.message.ttypes import MessageType
 from talos.client.Constants import Constants
-from talos.thrift.topic.ttypes import GetDescribeInfoRequest
-from talos.client.ScheduleInfoCache import ScheduleInfoCache
 from atomic import AtomicLong
 from talos.producer.BufferedMessageCount import BufferedMessageCount
 from talos.producer.UserMessage import UserMessage
@@ -18,14 +16,15 @@ from talos.client.TalosClientFactory import TalosClientFactory
 from talos.client.TalosErrors import InvalidArgumentError
 from talos.admin.TalosAdmin import TalosAdmin
 from talos.utils import Utils
+from talos.utils.FalconWriter import FalconWriter
 from talos.utils.Utils import synchronized
 from talos.producer.PartitionSender import PartitionSender
-from talos.utils.FalconWriter import FalconWriter
+from talos.thrift.common.ttypes import GalaxyTalosException
 from threading import Timer
 import threading
 import random
-import traceback
 import logging
+import traceback
 
 
 class PRODUCER_STATE:
@@ -38,11 +37,14 @@ class TalosProducer(object):
     logger = logging.getLogger("TalosProducer")
     partitionKeyMinLen = Constants.TALOS_PARTITION_KEY_LENGTH_MINIMAL
     partitionKeyMaxLen = Constants.TALOS_PARTITION_KEY_LENGTH_MAXIMAL
+    requestId = AtomicLong(1)
+    globalLock = threading.Condition()
     partitionNumber = int
     curPartitionId = int
 
     messageCallbackExecutors = threading.Thread
     partitionCheckExecutor = threading.Timer
+    partitionSenderMap = dict()
 
     falconWriter = FalconWriter
     producerMonitorThread = threading.Timer
@@ -52,12 +54,8 @@ class TalosProducer(object):
     def __init__(self, producerConfig=None, credential=None, topicName=None, talosAdmin=None,
                  talosClientFactory=None, topicTalosResourceName=None, partitioner=None,
                  topicAbnormalCallback=None, userMessageCallback=None):
-        self.requestId = AtomicLong(1)
-        self.globalLock = threading.Condition()
-        self.partitionSenderMap = dict()
         self.talosProducerConfig = producerConfig
         self.producerState = PRODUCER_STATE.ACTIVE
-        self.topicName = topicName
         if talosClientFactory:
             self.talosClientFactory = talosClientFactory
         else:
@@ -66,11 +64,12 @@ class TalosProducer(object):
             self.talosAdmin = talosAdmin
         else:
             self.talosAdmin = TalosAdmin(self.talosClientFactory)
+        self.topicName = topicName
         if topicTalosResourceName:
             self.topicTalosResourceName = topicTalosResourceName
         else:
-            self.topicTalosResourceName = self.talosAdmin.get_describe_info(
-                GetDescribeInfoRequest(self.topicName))
+            self.topicTalosResourceName = self.talosAdmin.get_topic_attribute(
+                GetTopicAttributeRequest(topicName=self.topicName))
         self.partitioner = partitioner
         self.topicAbnormalCallback = topicAbnormalCallback
         self.userMessageCallback = userMessageCallback
@@ -85,14 +84,7 @@ class TalosProducer(object):
                                                   self.maxBufferedMsgBytes)
         self.clientId = Utils.generate_client_id(producerConfig.get_client_ip(), "producer")
         self.synchronizedLock = threading.Lock()
-        # get scheduleInfo
-        self.scheduleInfoCache = ScheduleInfoCache().get_schedule_info_cache(
-            topicTalosResourceName=self.topicTalosResourceName.topicTalosResourceName,
-            talosClientConfig=producerConfig,
-            messageClient=self.talosClientFactory.new_message_client(),
-            talosClientFactory=self.talosClientFactory)
-        self.falconWriter = FalconWriter(
-            falconUrl=self.talosProducerConfig.get_falcon_url())
+        self.falconWriter = FalconWriter(falconUrl=self.talosProducerConfig.get_falcon_url())
 
         # getTopicTalosResourceName(producerConfig, credential);
         self.check_and_get_topic_info(self.topicTalosResourceName.topicTalosResourceName)
@@ -111,7 +103,10 @@ class TalosProducer(object):
             response = self.talosAdmin.get_topic_attribute(
                 GetTopicAttributeRequest(topicName=self.topicName))
         except Exception as e:
-            self.logger.error("Exception in CheckPartitionTask: " + e.message)
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
+            self.logger.error("Exception in CheckPartitionTask: "
+                              + str(traceback.format_exc()))
             if Utils.is_topic_not_exist(e):
                 self.disable_producer(e)
             return
@@ -154,90 +149,84 @@ class TalosProducer(object):
 
     @synchronized
     def add_user_message(self, msgList=None, partitionId=None):
-        try:
-            if not self.is_active():
-                raise ProducerNotActiveException("Producer is not active, current state: "
-                                                 + str(self.producerState))
+        if not self.is_active():
+            raise ProducerNotActiveException("Producer is not active, current state: "
+                                             + str(self.producerState))
 
-            # check total buffered message number
-            while self.bufferedCount.is_full():
-                with self.lock:
-                    try:
-                        self.logger.info("too many buffered messages, globalLock is active."
-                                         + " message number: " +
-                                         str(self.bufferedCount.get_buffered_msg_number())
-                                         + ", message bytes:  " +
-                                         str(self.bufferedCount.get_buffered_msg_bytes()))
-                        # release global lock but no notify
-                        self.globalLock.acquire()
-                        self.globalLock.wait()
-                        self.globalLock.release()
-                    except Exception as e:
-                        self.logger.error("addUserMessage global lock wait is interrupt."
-                                          + e.message)
+        # check total buffered message number
+        while self.bufferedCount.is_full():
+            with self.lock:
+                try:
+                    self.logger.info("too many buffered messages, globalLock is active."
+                                     + " message number: " +
+                                     str(self.bufferedCount.get_buffered_msg_number())
+                                     + ", message bytes:  " +
+                                     str(self.bufferedCount.get_buffered_msg_bytes()))
+                    # release global lock but no notify
+                    self.globalLock.acquire()
+                    self.globalLock.wait()
+                    self.globalLock.release()
+                except Exception as e:
+                    if isinstance(e, GalaxyTalosException):
+                        self.logger.error(e.errMsg)
+                    self.logger.error("addUserMessage global lock wait is interrupt."
+                                      + str(traceback.format_exc()))
 
-            if partitionId is None:
-                self.do_add_user_message(msgList)
-            else:
-                userMessageList = []
+        if not partitionId:
+            self.do_add_user_message(msgList)
+        else:
+            userMessageList = []
 
-                for message in msgList:
-                    # set timestamp and messageType if not set
-                    Utils.update_message(message, MessageType.BINARY)
-                    # check data validity
-                    Utils.check_message_validity(message, self.talosProducerConfig)
-                    userMessageList.append(UserMessage(message))
+            for message in msgList:
+                # set timestamp and messageType if not set
+                Utils.update_message(message, MessageType.BINARY)
+                # check data validity
+                Utils.check_message_validity(message)
+                userMessageList.append(UserMessage(message))
 
-                assert partitionId in self.partitionSenderMap
-                self.partitionSenderMap.get(partitionId).add_message(userMessageList)
-        except Exception as e:
-            self.logger.error("add_user_message func error: " + traceback.format_exc())
-            raise e
+            assert partitionId in self.partitionSenderMap
+            self.partitionSenderMap.get(partitionId).add_message(userMessageList)
 
     # @synchronized
     def do_add_user_message(self, msgList=None):
-        try:
-            # user can optionally set 'partitionKey' and 'sequenceNumber' when construct Message
-            partitionBufferMap = dict()
+        # user can optionally set 'partitionKey' and 'sequenceNumber' when construct Message
+        partitionBufferMap = dict()
 
-            # check / update curPartitionId
-            if self.should_update_partition():
-                self.curPartitionId = (self.curPartitionId + 1) % self.partitionNumber
-                self.lastUpdatePartitionIdTime = Utils.current_time_mills()
-                self.lastAddMsgNumber = 0
-            currentPartitionId = self.curPartitionId
-            self.lastAddMsgNumber += len(msgList)
+        # check / update curPartitionId
+        if self.should_update_partition():
+            self.curPartitionId = (self.curPartitionId + 1) % self.partitionNumber
+            self.lastUpdatePartitionIdTime = Utils.current_time_mills()
+            self.lastAddMsgNumber = 0
+        currentPartitionId = self.curPartitionId
+        self.lastAddMsgNumber += len(msgList)
 
-            partitionBufferMap[currentPartitionId] = []
+        partitionBufferMap[currentPartitionId] = []
 
-            for message in msgList:
-                # set timestamp and messageType if not set;
-                Utils.update_message(message, MessageType.BINARY)
-                # check data validity
-                Utils.check_message_validity(message, self.talosProducerConfig)
+        for message in msgList:
+            # set timestamp and messageType if not set;
+            Utils.update_message(message, MessageType.BINARY)
+            # check data validity
+            Utils.check_message_validity(message)
 
-                # check partitionKey setting and validity
-                if not message.partitionKey:
-                # straight forward put to cur partitionId queue
+            # check partitionKey setting and validity
+            if not message.partitionKey:
+            # straight forward put to cur partitionId queue
+                userMessage = UserMessage(message)
+                partitionBufferMap.get(currentPartitionId).append(userMessage)
+            else:
+                self.check_message_partition_key_validity(message.getPartitionKey())
+                # construct UserMessage and dispatch to buffer by partitionId
+                partitionId = self.get_partition_id(message.partitionKey)
+                if partitionId not in partitionBufferMap:
+                    partitionBufferMap[partitionId] = []
                     userMessage = UserMessage(message)
-                    partitionBufferMap.get(currentPartitionId).append(userMessage)
-                else:
-                    self.check_message_partition_key_validity(message.getPartitionKey())
-                    # construct UserMessage and dispatch to buffer by partitionId
-                    partitionId = self.get_partition_id(message.partitionKey)
-                    if partitionId not in partitionBufferMap:
-                        partitionBufferMap[partitionId] = []
-                        userMessage = UserMessage(message)
-                        partitionBufferMap.get(partitionId).append(userMessage)
+                    partitionBufferMap.get(partitionId).append(userMessage)
 
-            # add to partitionSender
-            for key, value in partitionBufferMap.items():
-                partitionId = key
-                assert partitionId in self.partitionSenderMap
-                self.partitionSenderMap.get(partitionId).add_message(value)
-        except Exception as e:
-            self.logger.error("do_add_user_message func error: " + traceback.format_exc())
-            raise e
+        # add to partitionSender
+        for key, value in partitionBufferMap.items():
+            partitionId = key
+            assert partitionId in self.partitionSenderMap
+            self.partitionSenderMap.get(partitionId).add_message(value)
 
     def should_update_partition(self):
         return (Utils.current_time_mills() - self.lastUpdatePartitionIdTime >=
@@ -245,10 +234,7 @@ class TalosProducer(object):
                                                     self.updatePartitionIdMsgNumber)
 
     def check_message_partition_key_validity(self, partitionKey=None):
-        try:
-            assert not partitionKey
-        except AssertionError as e:
-            raise e
+        assert not partitionKey
         if len(partitionKey) < self.partitionKeyMinLen or len(partitionKey) > self.partitionKeyMaxLen:
             raise InvalidArgumentError("Invalid partition key which length must be at "
                                        + "least " + str(self.partitionKeyMinLen) +
@@ -287,9 +273,7 @@ class TalosProducer(object):
         for key, value in self.partitionSenderMap.items():
             value.shutdown()
         self.partitionCheckExecutor.cancel()
-        if self.talosProducerConfig.is_open_client_monitor():
-            self.producerMonitorThread.cancel()
-        self.scheduleInfoCache.shut_down(self.topicTalosResourceName)
+        self.producerMonitorThread.cancel()
 
     def adjust_partition_sender(self, newPartitionNum=None):
         if self.partitionNumber < newPartitionNum:
@@ -338,7 +322,7 @@ class TalosProducer(object):
                                        + " not found")
 
         self.partitionNumber = response.topicAttribute.partitionNumber
-        self.curPartitionId = random.randint(0, self.partitionNumber-1)
+        self.curPartitionId = random.randint(0, self.partitionNumber)
         self.topicTalosResourceName = topicTalosResourceName
 
     def init_partition_sender(self):
@@ -352,7 +336,7 @@ class TalosProducer(object):
         self.partitionCheckExecutor = Timer(interval=self.talosProducerConfig.
                                             get_producer_check_partition_interval(),
                                             function=self.check_partition_task)
-        self.partitionCheckExecutor.setName("talos-producer-partitionCheckTask-" + self.topicName)
+        self.partitionCheckExecutor.setName("talos-producer-partitionCheck-" + self.topicName)
         self.partitionCheckExecutor.start()
 
     def init_producer_monitor_task(self):
@@ -375,4 +359,3 @@ class TalosProducer(object):
         for key, value in self.partitionSenderMap.items():
             jsonArray += value.get_falcon_data()
         self.falconWriter.push_falcon_data(jsonArray)
-
