@@ -22,7 +22,7 @@ class FalconWriter(object):
 
 	def push_falcon_data(self, falconData=None):
 		try:
-			resp = requests.post(self.falconUrl, json=falconData, headers=self.headers)
+			resp = requests.post(self.falconUrl, json=json.dumps(falconData), headers=self.headers)
 			if not resp.status_code == 200:
 				logger.error("Post data failed, StatusCode: " + str(resp.status_code))
 		except Exception as throwable:
